"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createEntry = createEntry;
exports.createId = createId;
exports.formatUrl = formatUrl;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _crypto = require("crypto");

var _pathToRegexp = require("path-to-regexp");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

const DEFAULT_PERMALINK = '/:category?/:slug';
const PERMALINK_CATEGORIES = ':category(.*)';

function formatUrl(data) {
  const {
    date,
    permalink = DEFAULT_PERMALINK
  } = data;
  const toUrl = (0, _pathToRegexp.compile)(permalink.replace(':category', PERMALINK_CATEGORIES));
  return toUrl(_objectSpread(_objectSpread({}, data), {}, {
    date: JSON.stringify(date).replace(/T.*Z/, '')
  }), {
    encode: v => encodeURI(v)
  });
}

function createId(path) {
  return (0, _crypto.createHash)('md5').update(path).digest('hex');
}
/**
 * Create a new Entry Object.
 * @param {Object} rawEntry
 * @param {Object} rawEntry.meta
 * @param {String} rawEntry.meta.filePath absolute path to the entry.
 * @param {String} rawEntry.meta.mimeType file mimeType.
 * @param {String} rawEntry.meta.name file name (without extension).
 * @param {String} rawEntry.meta.createdOn entry creation date. Optional.
 * @param {String} rawEntry.meta.path entry path (relative to folder where it was read from). Optional.
 * @param {String} rawEntry.meta.slug entry slug. Optional.
 * @param {Object} rawEntry.meta.extra entry extra data. Usually from frontmatter content. It can override other meta options. Optional.
 * @param {String} rawEntry.raw entry raw content.
 * @param {Any} rawEntry.content entry processed content.
 */


function createEntry({
  meta,
  raw,
  content
}) {
  const {
    filePath,
    mimeType,
    name,
    path,
    createdOn,
    date,
    slug,
    extra
  } = meta;

  const data = _objectSpread({
    __id: createId(filePath),
    mimeType,
    name,
    slug: slug || name.toLowerCase().replace(' ', '-'),
    category: path || undefined,
    date: date || JSON.parse(createdOn || JSON.stringify(new Date()))
  }, extra);

  return {
    data: _objectSpread(_objectSpread({}, data), {}, {
      year: String(new Date(data.date).getFullYear()),
      month: String(new Date(data.date).getMonth() + 1).padStart(2, '0'),
      day: String(new Date(data.date).getDate()).padStart(2, '0')
    }),
    content,
    raw
  };
}
//# sourceMappingURL=create.js.map