"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = fetcher;
Object.defineProperty(exports, "formatUrl", {
  enumerable: true,
  get: function () {
    return _create.formatUrl;
  }
});
exports.getData = getData;
exports.getDataFilterBy = getDataFilterBy;
exports.getPost = getPost;
exports.getPosts = getPosts;
exports.getPostsFilterBy = getPostsFilterBy;

var _metadata = require("./metadata");

var _load = require("./load");

var _create = require("./create");

function fetcher(filter) {
  return {
    getData: async () => getDataFilterBy(filter),
    getPosts: async () => getPostsFilterBy(filter),
    getPost
  };
}

async function dataFilterBy(filter) {
  const _meta = (await (0, _metadata.metadata)()).map(data => ({
    data
  }));

  const _filtered = filter ? _meta.filter(filter) : _meta;

  return _filtered.map(({
    data
  }) => data);
}

async function getDataFilterBy(filter) {
  return dataFilterBy(filter);
}

async function getData() {
  return getDataFilterBy();
}

async function getPostsFilterBy(filter) {
  const _filtered = await dataFilterBy(filter);

  const ids = _filtered.map(data => data.__id);

  return filter && !ids.length ? [] : (0, _load.load)(ids);
}

async function getPosts() {
  return getPostsFilterBy();
}

async function getPost(params) {
  const _meta = await (0, _metadata.metadata)();

  const entry = params && _meta.find(data => {
    // first check by __id
    if (params.__id && params.__id === data.__id) return true;

    for (const [k, v] of Object.entries(params)) {
      if (!data[k] || (Array.isArray(v) ? !Array.isArray(data[k]) ? !v.includes(data[k]) : v.some(value => !data[k].includes(value)) : data[k] !== v)) {
        return false;
      }
    }

    return true;
  });

  const [found] = entry ? await (0, _load.load)(entry.__id) : [null];
  return found;
}
//# sourceMappingURL=fetcher.js.map