"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.run = run;
exports.subscribe = subscribe;
exports.subscribeEntryChange = subscribeEntryChange;

var _events = _interopRequireDefault(require("events"));

var _create = require("../entries/create");

var _compile = require("./compile");

const emitter = new _events.default();
const entries = new Map();
let posts = [];
let bootstraped = false;
/**
 * subscribe
 * @param {*} fn
 */

function subscribe(fn) {
  const handler = () => fn(posts);

  emitter.on('update', handler);
  return function unsubscribe() {
    emitter.off('update', handler);
  };
}

function subscribeEntryChange(fn) {
  emitter.on('entry.change', fn);
  return function unsubscribe() {
    emitter.off('entry.change', fn);
  };
}

emitter.on('entries.update', __id => {
  processEntries();
  emitter.emit('entry.change', __id);
});

async function upsertEntries() {
  const {
    sources = [],
    builders = []
  } = (0, _compile.compile)();

  async function build(buildOptions) {
    for (const build of builders) {
      await build(buildOptions, {
        create: createOptions => {
          const entry = (0, _create.createEntry)(createOptions);
          entries.set(entry.data.__id, entry);
          if (bootstraped) emitter.emit('entries.update', entry.data.__id);
        }
      });
    }
  }

  function remove(removeOptions) {
    const __id = (0, _create.createId)(removeOptions.filePath);

    entries.delete(__id);
    if (bootstraped) emitter.emit('entries.update', __id);
  }

  for (const source of sources) {
    await source({
      build,
      remove
    });
  }
}

async function processEntries() {
  const {
    transformers = [],
    cleaners = [],
    filters = [],
    sorters = []
  } = (0, _compile.compile)();
  posts = JSON.parse(JSON.stringify(Array.from(entries.values()))); // deep clone

  for (const transform of transformers) {
    posts = await transform(posts);
  }

  for (const cleanup of cleaners) {
    posts = await cleanup(posts);
  }

  for (const filter of filters) {
    posts = await filter(posts);
  }

  for (const sort of sorters) {
    posts = await sort(posts);
  }

  if (bootstraped) emitter.emit('update');
}
/**
 *
 */


async function run() {
  await upsertEntries();
  await processEntries();
  bootstraped = true;
  return posts;
}
//# sourceMappingURL=bootstrap.js.map