"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.build = build;
exports.cleanup = cleanup;

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _frontmatter = _interopRequireDefault(require("frontmatter"));

var _parser = _interopRequireDefault(require("./parser"));

var _unistUtilRemovePosition = _interopRequireDefault(require("unist-util-remove-position"));

const _excluded = ["load"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function normalizeDate(value, {
  path
}) {
  if (!value) return;

  try {
    return new Date(value);
  } catch (e) {
    console.warn(`Invalid date in frontmatter at: ${path}`);
  }
}

function createOptions(source, raw, options) {
  const {
    data: extra = {},
    content: text
  } = (0, _frontmatter.default)(raw);
  const instance = (0, _parser.default)(options); // second text argument avoids positoin information being removed in rehype-raw

  const content = instance.runSync(instance.parse(text), text);
  if (extra.date) extra.date = normalizeDate(extra.date, source);
  return {
    meta: _objectSpread(_objectSpread({}, source), {}, {
      extra: _objectSpread(_objectSpread({}, source.extra), extra)
    }),
    content,
    raw
  };
}
/**
 * build
 * @param {Object} options
 * @param {Array} options.remark plugins for remark
 * @param {Array} options.rehype plugins for rehype
 * @param {Object} buildOptions
 * @param {Object} action
 * @param {Function} action.create
 */


async function build(options, _ref, {
  create
}) {
  let {
    load
  } = _ref,
      source = (0, _objectWithoutProperties2.default)(_ref, _excluded);

  if (source.mimeType === 'text/markdown') {
    const raw = await load();
    create(createOptions(source, raw, options));
  }
}
/**
 * cleanup
 * @param {Object} options
 * @param {Boolean} options.raw set to true to keep raw value in post object. Default to false.
 * @param {Boolean} options.position set to true to keep position information in content hast. Default to false.
 * @param {Array} posts
 */


function cleanup({
  raw = false,
  position = false
}, posts) {
  return posts.map(post => {
    if (post.data.mimeType === 'text/markdown') {
      if (!position) post.content = (0, _unistUtilRemovePosition.default)(post.content, true
      /* hard delete */
      );
      if (!raw) delete post.raw;
    }

    return post;
  });
}
//# sourceMappingURL=index.js.map